@@ -12,14 +12,14 @@ import tqdm
 
 import rpi_camera_colony
 from rpi_camera_colony.config.config import get_local_ip_address
-from rpi_camera_colony.config.config import setup_logging
-from rpi_camera_colony.tools.comms import SocketCommunication
-from rpi_camera_colony.tools.files import get_datestr
+from rpi_camera_colony.config.config import setup_logging_via_socket
+from rpi_camera_colony.files import get_datestr
+from rpi_camera_colony.network_communication import SocketCommunication
 
 
 def parse_args_for_piacquisitioncontrol():
     parser = argparse.ArgumentParser(
-        description="Input arguments",
+        description="RPi Camera Colony: Acquisition",
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     parser_general = parser.add_argument_group("General")
@@ -51,14 +51,14 @@ def parse_args_for_piacquisitioncontrol():
     parser_acq_ctrl.add_argument(
         "--acquisition-name",
         "-n",
-        default="test_recording__" + get_datestr(),
+        default="_test_rcc_acquisition_parser__" + get_datestr(),
         type=str,
         help="Base name for recording folder and files.",
     )
     parser_acq_ctrl.add_argument(
         "--acquisition-group",
         "-g",
-        default="test_group",
+        default="_test_acq_group",
         type=str,
         help="Base name for recording group folders.",
     )
@@ -106,6 +106,21 @@ def parse_args_for_piacquisitioncontrol():
         default=False,
         action="store_true",
     )
+    parser_acq_ctrl.add_argument(
+        "-fps",
+        "--framerate",
+        default=30,
+        type=int,
+        help="Framerate",
+    )
+    parser_acq_ctrl.add_argument(
+        "-res",
+        "--resolution",
+        nargs="+",
+        default=(1600, 1200),
+        type=int,
+        help="Resolution",
+    )
     return parser.parse_args()
 
 
@@ -128,7 +143,7 @@ def main():
         auto_open=True,
     )
 
-    setup_logging(
+    setup_logging_via_socket(
         level=args.log_level,
         address_or_socket=socket_wrapper.socket,
         root_topic=args.instance_name,
@@ -157,7 +172,6 @@ def main():
         while (time.time() - start_time) < max_time and c.active:
             try:
                 time.sleep(print_interval)
-                print(f"Run time: {round(time.time() - start_time, 2)}")
                 progress.update(n=print_interval)
             except KeyboardInterrupt:
                 c.active = False
